@@ -19,7 +19,7 @@ retry_strategy = Retry(
     allowed_methods=frozenset({'DELETE', 'GET', 'HEAD', 'OPTIONS', 'POST', 'PUT', 'TRACE'})
 )
 adapter = HTTPAdapter(max_retries=retry_strategy)
-DEFAULT_TIMEOUT=5
+DEFAULT_TIMEOUT=20
 http = requests.Session()
 # set the raise_for_status flag to raise exceptions on http status codes other than 200
 http.hooks = {
@@ -147,6 +147,11 @@ class NXGclient:
             input_vcf_id = stage['input_data']['input_vcf_text_id']
             input_data['vcf_download_uri'] = self.base_uri + '/download_vcf/' + input_vcf_id
 
+        # set a pointer to the input sequence fasta uri
+        if 'input_neoepitopes_id' in stage['input_data']:
+            input_neoepitopes_id = stage['input_data']['input_neoepitopes_id']
+            input_data['neoepitopes_download_uri'] = self.base_uri + '/download_neoepitopes/' + input_neoepitopes_id
+            print("neoepitopes_download_uri: " + input_data['neoepitopes_download_uri'])
         #TODO if this is a 'filter' stage, add the input_stage_id information
         # currently, we can't pull this information from the stage endpoint
         if stage['stage_type'] == 'filter':
@@ -219,6 +224,7 @@ def api2cmd_input(tool_group, api_inputs = {}, stage_id = None):
         'mhci': api2cmd_input_mhci,
         'mhcii': api2cmd_input_mhci,
         'peptide_variant_comparison': api2cmd_input_mhci,
+        'phbr': api2cmd_input_phbr,
         'mutgen': api2cmd_input_mutgen,
         'cluster': api2cmd_input_cluster,
         'pepmatch': api2cmd_input_pepmatch
@@ -228,6 +234,29 @@ def api2cmd_input(tool_group, api_inputs = {}, stage_id = None):
     
     return action_map[tool_group](api_inputs, stage_id)
 
+def api2cmd_input_phbr(api_inputs = {}, stage_id = None):
+    """Given a dict of stage input_data OR a stage_id,
+    return the JSON necessary for the command line tool"""
+
+    if stage_id != None:
+        api_inputs = NXGclient().get_stage_inputs(stage_id)
+
+    api_data = api_inputs['input_parameters']['data']
+
+    # start with the input parameters
+    # NOTE: Here we are assuming only 1 predictor is passed
+    cmd_input = copy.deepcopy(api_data)
+
+    # retrieve the input sequence fasta
+    input_sequence_file = save_file_from_URI(api_inputs['neoepitopes_download_uri'])
+    with open(input_sequence_file, "r") as f:
+        input_fasta_string = f.read()
+
+    # now add the sequence text
+    cmd_input['input_neoepitopes'] = input_fasta_string
+
+    return cmd_input
+
 def api2cmd_input_pepmatch(api_inputs = {}, stage_id = None):
     """Given a dict of stage input_data OR a stage_id,
     return the JSON necessary for the command line tool"""
@@ -259,9 +288,9 @@ def api2cmd_input_pepmatch(api_inputs = {}, stage_id = None):
 
     if stage_id != None:
         api_inputs = NXGclient().get_stage_inputs(stage_id)
-    
+
     api_data = api_inputs['input_parameters']['data']
-    
+
     # start with the input parameters
     # NOTE: Here we are assuming only 1 predictor is passed
     cmd_input = copy.deepcopy(api_data)
@@ -273,7 +302,7 @@ def api2cmd_input_pepmatch(api_inputs = {}, stage_id = None):
 
     # now add the sequence text
     cmd_input['input_sequence_text'] = input_fasta_string
-    
+
     return cmd_input
  
 # functions to handle conversion between formats
@@ -325,9 +354,9 @@ def api2cmd_input_cluster(api_inputs = {}, stage_id = None):
         
     if stage_id != None:
         api_inputs = NXGclient().get_stage_inputs(stage_id)
-    
+
     api_data = api_inputs['input_parameters']['data']
-    
+
     # start with the input parameters
     # NOTE: Here we are assuming only 1 predictor is passed
     cmd_input = { 'cluster_pct_identity': api_data['cluster_pct_identity'],
@@ -341,7 +370,7 @@ def api2cmd_input_cluster(api_inputs = {}, stage_id = None):
 
     # now add the sequence text
     cmd_input['input_sequence_text'] = input_fasta_string
-    
+
     return cmd_input       
        
 def api2cmd_input_mutgen(api_inputs = {}, stage_id = None):
@@ -410,9 +439,9 @@ def cmd2api_output_mhci(cmd_output):
     
     for r in api_output['results']:
         
-        # change 'result_type' to 'type'
-        r['type'] = r['result_type']
-        del r['result_type']
+        # change 'result_type' to 'type' if it is used
+        if 'type' not in r and 'result_type' in r:
+            r['type'] = r.pop('result_type')
         
         # skip this result if no table columns are included
         if 'table_columns' not in r:
