@@ -230,6 +230,13 @@ def split_parameters(input_data, split_inputs_dir=None):
     peptide_list = input_data.pop('peptide_list', '')
     input_sequence_fasta_uri = input_data.pop('input_sequence_fasta_uri', '')
     alleles = input_data.get('alleles').split(',')
+    # remove empty alleles
+    alleles = [allele.strip() for allele in alleles if allele.strip()]
+    # remove repeated alleles but keep the original order
+    # and print a warning if there are repeated alleles
+    if len(alleles) != len(set(alleles)):
+        print('warning: repeated alleles found, removing duplicates')
+        alleles = list(dict.fromkeys(alleles))
     predictors = input_data.get('predictors')
     allele_validator = Allele_Validator()
     if input_sequence_fasta_uri:
