@@ -500,12 +500,16 @@ def commandline_input_prediction(options, args):
         else:
             peptide_list = input_data.get('peptide_list')
             seq_file_type = 'peptides'
-
             if not options.assume_valid_flag and maximum_length:
+                valid_peptides = []
                 for peptide in peptide_list:
                     if len(peptide) > maximum_length or len(peptide) < minimum_length:
-                        peptide_list.remove(peptide)
                         warnings.append('peptide "%s" length is out of valid range (%s)' % (peptide, '%d-%d' % (minimum_length,maximum_length)))
+                    else:
+                        valid_peptides.append(peptide)
+                peptide_list = valid_peptides
+            if not peptide_list:
+                raise ValueError('No valid peptides found in the input list. Please check the the input and peptide length.')
             to_delete = []
             with tempfile.NamedTemporaryFile(mode='w', delete=False) as tmp_peptides_file:
                 fname = tmp_peptides_file.name
@@ -521,11 +525,12 @@ def commandline_input_prediction(options, args):
         for predictor in predictors:
             # add recommended as alias
             method = predictor.get('method', '').replace('recommended_epitope','netmhcpan_el').replace('recommended_binding','netmhcpan_ba')
-            allele_warnings, allele_errors = validate_allele(input_allele, method)
-            if allele_errors:
-                raise ValueError('\n'.join(allele_errors))
-            elif allele_warnings:
-                additional_result_info.setdefault('warnings', []).extend(warnings)
+            if method != "immunogenicity" or predictor.get('mask_choice','') == 'by_allele':
+                allele_warnings, allele_errors = validate_allele(input_allele, method)
+                if allele_errors:
+                    raise ValueError('\n'.join(allele_errors))
+                elif allele_warnings:
+                    additional_result_info.setdefault('warnings', []).extend(warnings)
             predictor_type = predictor.get('type')
             # if not method or method==type: return type else: join
             predictor_source = '.'.join(filter(None, dict.fromkeys((predictor_type, method))))
